package org.apache.maven.archiva.repository.audit;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * AuditLog - Audit Log. 
 *
 * @author <a href="mailto:joakime@apache.org">Joakim Erdfelt</a>
 * @version $Id$
 * 
 * @plexus.component role="org.apache.maven.archiva.repository.audit.AuditListener"
 *                   role-hint="logging"
 */
public class AuditLog
    implements AuditListener
{
    public static final Logger logger = LoggerFactory.getLogger( "org.apache.archiva.AuditLog" );
    
    private static final char DELIM = ' '; 

    /**
     * Creates a log message in the following format ...
     * 
     * "{repository_id} {user_id} {remote_ip} \"{resource}\" \"{action}\""
     */
    public void auditEvent( AuditEvent event )
    {
        StringBuffer msg = new StringBuffer();
        msg.append( event.getRepositoryId() ).append( DELIM );
        msg.append( event.getUserId() ).append( DELIM );
        msg.append( event.getRemoteIP() ).append( DELIM );
        msg.append( '\"' ).append( event.getResource() ).append( '\"' ).append( DELIM );
        msg.append( '\"' ).append( event.getAction() ).append( '\"' );

        logger.info( msg.toString() );
    }
}
